# frozen_string_literal: true

require "dry/core"
